@@ -45,7 +45,7 @@ class Model(dict):
         if isinstance(obj,Model):
             return obj.save()
         else:
-            raise AttributeError(r"'%s' does not inherit Model." %type(obj))
+            raise AttributeError(r"'%s' does not inherit 'Model'." %type(obj))
 
     def delete(self,**kw):
         sql = 'delete from %s where '%self.__table__
@@ -66,26 +66,54 @@ class Model(dict):
         L.i('SQL: %s' % self["sql"])
         return self
 
+    @staticmethod
+    def delete_by_id(obj):
+        if isinstance(obj, Model):
+            key=obj.__get_key__('id')
+            if key:
+                return obj.delete(id=obj.id).execute()
+            else:
+                raise AttributeError(r"'%s' object has no attribute 'id'." % type(obj))
+
+        else:
+            raise AttributeError(r"'%s' does not inherit 'Model'." % type(obj))
+
     def update(self,**kw):
         sql = 'update %s set ' % self.__table__
         tag = True
         for a in kw.keys():
-            key = None
-            try:
-                key = self.__getattribute__(a)
-            except:
-                key = self.__get_key__(a)
+            key = a
+            # try:
+            #     key = self.__getattribute__(a)
+            # except:
+            #     key = self.__get_key__(a)
 
             if tag:
                 sql = sql + " %s='%s', " % (key, kw.get(a))
                 tag = False
             else:
                 sql = sql + " %s='%s', " % (key, kw.get(a))
-            sql=sql[0:-2]
+        sql=sql[0:-2]
         self["sql"] = sql
         L.i('SQL: %s' % self["sql"])
         return self
 
+    @staticmethod
+    def update_by_id(obj):
+        if isinstance(obj, Model):
+            key = obj.__get_key__('id')
+            if key:
+                update_cloums={}
+                for k, v in obj.__mappings__.iteritems():
+                    if getattr(obj, k, None):
+                        update_cloums[v.name]=str(getattr(obj, k, None))
+                return obj.update(**update_cloums).where(id=obj.id).execute()
+            else:
+                raise AttributeError(r"'%s' object has no attribute 'id'." % type(obj))
+
+        else:
+            raise AttributeError(r"'%s' does not inherit 'Model'." % type(obj))
+
     def search(self,**kw):
         sql = 'select * from %s where ' % self.__table__
         tag=True
@@ -105,6 +133,23 @@ class Model(dict):
         L.i('SQL: %s' % self["sql"])
         return self
 
+    @staticmethod
+    def search_all(obj):
+        if isinstance(obj, Model):
+            sql = 'select * from %s ' % obj.__table__
+            obj["sql"] = sql
+            L.i('SQL: %s' % obj["sql"])
+            return obj.execute()
+        else:
+            raise AttributeError(r"'%s' does not inherit 'Model'." % type(obj))
+
+    def search_all(self):
+        sql = 'select * from %s ' % self.__table__
+        self["sql"] = sql
+        L.i('SQL: %s' % self["sql"])
+        return self.execute()
+
+
     def __get_key__(self,name):
         key=None
         for k, v in self.__mappings__.iteritems():
