@@ -16,7 +16,7 @@ from ormdb.User import User
 
 def saveData():
     # 创建一个实例：
-    # u = User(name='Michael', email='test_unit@ormdb.org', password='my-pwd')
+    u = User(id=12,name="Json", email='test_unit@ormdb.org', password='123456')
     # dd=User.add(u)
     # print dd
     # 保存到数据库：
@@ -26,7 +26,8 @@ def saveData():
     # dd=User().native("select * from user").execute()
     # dd=User().search().like("id","1").execute()
     # print dd
-    User().update(name="Jieke").where(id=12).execute()
-
+    # User().update(name="Jieke").where(id=12).execute()
+    print u.search_all()
 saveData()
 
+
